==> libbpp-phyl_2.0.3.orig.tar.gz: bpp-phyl-2.0.3/src/Bpp/Phyl/Model/RateDistributionFactory.cpp <==
//
// File: RateDistributionFactory.cpp
// Created by: Julien Dutheil
//             Vincent Ranwez
// Created on: Fri apr 14 11:11 2006
//

/*
Copyright or © or Copr. CNRS, (November 16, 2004, 2005, 2006)

This software is a computer program whose purpose is to provide classes
for phylogenetic data analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#include "RateDistributionFactory.h"

using namespace bpp;
using namespace std;

const string RateDistributionFactory::CONSTANT_DISTRIBUTION = "Constant";
const string RateDistributionFactory::GAMMA_DISTRIBUTION = "Gamma";

DiscreteDistribution * RateDistributionFactory::createDiscreteDistribution(const string& distName, unsigned int nbClasses) throw (Exception)
{
       if(distName == GAMMA_DISTRIBUTION) return new GammaDiscreteDistribution(nbClasses);
  else if(distName == CONSTANT_DISTRIBUTION) return new ConstantDistribution(1.);
  else throw Exception("RateDistributionFactory::createDistribution(). Unknown rate distribution: " + distName);
}

==> libbpp-phyl_2.1.0.orig.tar.gz: bpp-phyl-2.1.0/src/Bpp/Phyl/Model/RateDistributionFactory.cpp <==
//
// File: RateDistributionFactory.cpp
// Created by: Julien Dutheil
//             Vincent Ranwez
// Created on: Fri apr 14 11:11 2006
//

/*
Copyright or © or Copr. Bio++ Development Team, (November 16, 2004, 2005, 2006)

This software is a computer program whose purpose is to provide classes
for phylogenetic data analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#include "RateDistributionFactory.h"

#include "RateDistribution/ConstantRateDistribution.h"
#include "RateDistribution/GammaDiscreteRateDistribution.h"
#include "RateDistribution/GaussianDiscreteRateDistribution.h"
#include "RateDistribution/ExponentialDiscreteRateDistribution.h"

using namespace bpp;
using namespace std;

const string RateDistributionFactory::CONSTANT_DISTRIBUTION = "Constant";
const string RateDistributionFactory::GAMMA_DISTRIBUTION = "Gamma";
const string RateDistributionFactory::GAUSSIAN_DISTRIBUTION = "Gaussian";
const string RateDistributionFactory::EXPONENTIAL_DISTRIBUTION = "Exponential";

DiscreteDistribution* RateDistributionFactory::createDiscreteDistribution(const string& distName, unsigned int nbClasses) throw (Exception)
{
       if (distName == GAMMA_DISTRIBUTION) return new GammaDiscreteRateDistribution(nbClasses);
  else if (distName == GAUSSIAN_DISTRIBUTION) return new GaussianDiscreteRateDistribution(nbClasses, 1.);
  else if (distName == EXPONENTIAL_DISTRIBUTION) return new ExponentialDiscreteRateDistribution(nbClasses);
  else if (distName == CONSTANT_DISTRIBUTION) return new ConstantRateDistribution();
  else throw Exception("RateDistributionFactory::createDistribution(). Unknown rate distribution: " + distName);
}
